@@ -26,6 +26,24 @@ cc_item_flags_get_type(void) {
 
 	return etype;
 }
+/* enumerations from "cc-unit.h" */
+#include "cc-unit.h"
+GType
+cc_unit_get_type(void) {
+	static GType etype = 0;
+	if(!etype) {
+		static const GEnumValue values[] = {
+			{CC_UNIT_DISPLAY_PIXEL, "CC_UNIT_DISPLAY_PIXEL", N_("display-pixel")},
+			{CC_UNIT_POINT, "CC_UNIT_POINT", N_("point")},
+			{CC_UNIT_PT, "CC_UNIT_PT", N_("pt")},
+			{0, NULL, NULL}
+		};
+
+		etype = g_enum_register_static("CcUnit", values);
+	}
+
+	return etype;
+}
 /* enumerations from "cc-utils.h" */
 #include "cc-utils.h"
 GType
