@@ -59,7 +59,7 @@ cc_line_clear(CcLine* self) {
 
 void
 cc_line_line(CcLine* self, gdouble x, gdouble y) {
-	struct CcSegment segment =  {CC_SEGMENT_LINE, x, y};
+	struct CcSegment segment = {CC_SEGMENT_LINE, x, y};
 	g_array_append_val(P(self)->segments, segment);
 
 	cc_item_update_bounds(CC_ITEM(self), &segment);
@@ -70,7 +70,7 @@ cc_line_move(CcLine* self, gdouble x, gdouble y) {
 	struct CcSegment segment = {CC_SEGMENT_MOVE, x, y};
 	g_array_append_val(P(self)->segments, segment);
 
-	cc_item_update_bounds(CC_ITEM(self), NULL);
+	cc_item_update_bounds(CC_ITEM(self), &segment);
 }
 
 /* GType */
@@ -103,7 +103,7 @@ cl_update_bounds(CcItem* item, CcView const* view, gpointer data) {
 		return;
 	}
 
-	gdouble half_width = ceil(/* FIXME: cc_shape_get_width(CC_SHAPE(item), view)*/ CC_SHAPE(item)->width / 2.0);
+	gdouble half_width = ceil(cc_shape_get_width(CC_SHAPE(item), view) / 2.0);
 	if(G_LIKELY(segment && bounds)) {
 		struct CcSegment seg = g_array_index(P(self)->segments, struct CcSegment, P(self)->segments->len - 2); // the formerly last one
 		CcDRect dirty = {
@@ -118,7 +118,11 @@ cl_update_bounds(CcItem* item, CcView const* view, gpointer data) {
 		cc_item_dirty(item, view, dirty);
 
 		cc_item_bounds_changed(item, view);
-	} else if(G_UNLIKELY(!bounds && P(self)->segments->len)) {
+	}
+	else if(bounds && !P(self)->segments->len) {
+		cc_hash_map_remove(item->bounds, view);
+	}
+	else if(G_UNLIKELY(!bounds && P(self)->segments->len)) {
 		guint i = 0;
 		CcDRect rect;
 		segment = &g_array_index(P(self)->segments, struct CcSegment, i);
@@ -147,6 +151,7 @@ cl_path(CcShape* shape, CcView* view, cairo_t* cr) {
 	struct CcSegment* segment,
 		        * last = &g_array_index(P(self)->segments, struct CcSegment, P(self)->segments->len - 1);
 	gdouble x, y;
+	gdouble w = cc_shape_get_width(shape, view);
 
 	cairo_set_line_join(cr, CAIRO_LINE_JOIN_ROUND);
 	cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
@@ -158,7 +163,6 @@ cl_path(CcShape* shape, CcView* view, cairo_t* cr) {
 		cc_view_world_to_window(view, &x, &y);
 
 		if(CC_ITEM_GRID_ALIGNED(shape)) {
-			gdouble w = shape->width;
 			cc_point_grid_align(&x, &y, &w);
 		}
 
