@@ -42,6 +42,8 @@ struct CcViewWidgetPrivate {
 #endif
 };
 
+#define P(i) (G_TYPE_INSTANCE_GET_PRIVATE ((i), CC_TYPE_VIEW_WIDGET, struct CcViewWidgetPrivate))
+
 /**
  * cc_view_widget_get_center_view:
  * @self: a #CcViewWidget
@@ -103,7 +105,10 @@ cc_view_widget_new_root(CcItem* root) {
 }
 
 static gboolean
-cvw_redraw_timeout(CcViewWidget* self) {
+cvw_redraw_timeout (CcViewWidget* self)
+{
+	g_return_val_if_fail (GTK_IS_WIDGET (self), TRUE);
+
 	gdk_window_invalidate_region(GTK_WIDGET(self)->window, self->priv->dirty_region, FALSE);
 
 	gdk_region_destroy(self->priv->dirty_region);
@@ -164,7 +169,7 @@ cvw_set_dirty(CcViewWidget* self, CcDRect dirty) {
 
 static CcDRect const*
 cvw_get_real_view(CcViewWidget* self) {
-	CcDRect rect = {0.0, 0.0, 0.0, 0.0};
+	static const CcDRect default_view = {0.0, 0.0, 0.0, 0.0};
 	CcDRect const* retval = NULL;
 
 	if(self->scrolled_region) {
@@ -174,7 +179,7 @@ cvw_get_real_view(CcViewWidget* self) {
 	}
 
 	if(!retval) {
-		retval = &rect;
+		retval = &default_view;
 	}
 
 	return retval;
@@ -281,7 +286,6 @@ cvw_update_adjustment_allocation(GtkAdjustment* adjustment, gdouble size, gboole
 		     "page-size",      size,
 		     "page-increment", size,
 		     "step-increment", size > 20 ? 10.0 : 1.0,
-#warning "FIXME: let this scale up to bigger values"
 		     NULL);
 
 	if(update_adjustment) {
@@ -367,7 +371,8 @@ cc_view_widget_init(CcViewWidget* self) {
 }
 
 static void
-cvw_dispose(GObject* object) {
+cvw_dispose (GObject* object)
+{
 	CcViewWidget* self = CC_VIEW_WIDGET(object);
 	if(self->disposed) {
 		return;
@@ -383,6 +388,17 @@ cvw_dispose(GObject* object) {
 	G_OBJECT_CLASS(cc_view_widget_parent_class)->dispose(object);
 }
 
+static void
+view_widget_finalize (GObject* object)
+{
+	if (P(object)->redraw_timeout) {
+		g_source_remove (P(object)->redraw_timeout);
+		P(object)->redraw_timeout = 0;
+	}
+
+	G_OBJECT_CLASS (cc_view_widget_parent_class)->finalize (object);
+}
+
 static void
 cvw_get_property(GObject* object, guint prop_id, GValue* value, GParamSpec* pspec) {
 	CcViewWidget* self = CC_VIEW_WIDGET(object);
@@ -500,7 +516,9 @@ cvw_update_vadjustment_root(CcViewWidget* self, gboolean update_adjustment) {
 }
 
 static void
-cvw_set_scrolled_region(CcViewWidget* self, CcDRect* scrolled_region) {
+cvw_set_scrolled_region(CcViewWidget * self,
+			CcDRect const* scrolled_region)
+{
 	if(self->scrolled_region == scrolled_region) {
 		return;
 	}
@@ -591,7 +609,7 @@ cvw_event(GtkWidget* widget, GdkEvent* event) {
 		if(self->grabbed) {
 			item = self->grabbed;
 		} else {
-			cc_item_distance(self->root, item_event->button.x, item_event->button.y, &item);
+			cc_item_distance(self->root, CC_VIEW (self), item_event->button.x, item_event->button.y, &item);
 		}
 		if(item) {
 			g_signal_emit_by_name(item, "event", view, item_event, &retval);
@@ -627,7 +645,7 @@ cvw_event(GtkWidget* widget, GdkEvent* event) {
 
 			cc_view_window_to_world(CC_VIEW(self), &item_event->motion.x, &item_event->motion.y);
 			if(self->grabbed) {
-				if(0.0 < cc_item_distance(self->grabbed, item_event->motion.x, item_event->motion.y, &item)) {
+				if(0.0 < cc_item_distance(self->grabbed, CC_VIEW (self), item_event->motion.x, item_event->motion.y, &item)) {
 					if(self->over_grabbed) {
 						g_signal_emit_by_name(self->grabbed, "event", view, &cr, &retval2);
 						self->over_grabbed = FALSE;
@@ -641,7 +659,7 @@ cvw_event(GtkWidget* widget, GdkEvent* event) {
 				}
 				item = self->grabbed;
 			} else {
-				cc_item_distance(self->root, item_event->motion.x, item_event->motion.y, &item);
+				cc_item_distance(self->root, CC_VIEW (self), item_event->motion.x, item_event->motion.y, &item);
 				if(item != self->current) {
 					cc_view_window_to_world(CC_VIEW(self), &cr.x, &cr.y);
 					if(self->current) {
@@ -786,7 +804,7 @@ cvw_size_request(GtkWidget* widget, GtkRequisition* requisition) {
 	if(!self->v_adjustment && all_bounds) {
 		requisition->height = self->zoom * all_bounds->y2 + 1.0;
 	} else {
-		requisition->width = 0.0;
+		requisition->height = 0.0;
 	}
 }
 
@@ -816,8 +834,7 @@ cvw_set_adjustment(CcViewWidget* self, GtkAdjustment* new_adjustment, GtkAdjustm
 			g_object_unref(*old_adjustment);
 		}
 
-		*old_adjustment = g_object_ref(new_adjustment);
-		gtk_object_sink(GTK_OBJECT(*old_adjustment));
+		*old_adjustment = g_object_ref_sink (new_adjustment);
 
 		g_signal_connect_swapped(*old_adjustment, "changed",
 					 G_CALLBACK(cvw_update_matrix), self);
@@ -861,6 +878,7 @@ cc_view_widget_class_init(CcViewWidgetClass* self_class) {
 	/* GObjectClass */
 	go_class = G_OBJECT_CLASS(self_class);
 	go_class->dispose      = cvw_dispose;
+	go_class->finalize     = view_widget_finalize;
 	go_class->get_property = cvw_get_property;
 	go_class->set_property = cvw_set_property;
 
@@ -990,7 +1008,10 @@ cvw_ungrab_item(CcView* view, CcItem* item, guint32 time) {
 }
 
 static void
-cvw_window_to_world(CcView* view, gdouble* x, gdouble* y) {
+cvw_window_to_world(CcView const* view,
+		    gdouble     * x,
+		    gdouble     * y)
+{
 	cairo_matrix_t inverse;
 
 	memcpy(&inverse, &CC_VIEW_WIDGET(view)->display_matrix, sizeof(cairo_matrix_t));
@@ -1000,13 +1021,18 @@ cvw_window_to_world(CcView* view, gdouble* x, gdouble* y) {
 }
 
 static void
-cvw_world_to_window(CcView* view, gdouble* x, gdouble* y) {
+cvw_world_to_window(CcView const* view,
+		    gdouble     * x,
+		    gdouble     * y)
+{
 	gdouble tx, ty;
 	cairo_matrix_transform_point(&CC_VIEW_WIDGET(view)->display_matrix, x ? x : &tx, y ? y : &ty);
 }
 
 static void
-cvw_world_to_window_distance(CcView* view, gdouble* x, gdouble* y) {
+cvw_world_to_window_distance(CcView const* view,
+			     gdouble     * x,
+			     gdouble     * y) {
 	gdouble tx, ty;
 	cairo_matrix_transform_distance(&CC_VIEW_WIDGET(view)->display_matrix, x ? x : &tx, y ? y : &ty);
 }
