@@ -21,7 +21,7 @@
  * USA
  */
 
-#include "credits.h"
+#include "main.h"
 
 #include <gtk/gtklabel.h>
 
