@@ -28,12 +28,18 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkliststore.h>
 #include <gtk/gtknotebook.h>
+#include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtktreemodelsort.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeview.h>
 
 #include <ccc/glib-helpers.h>
 
+#ifdef HAVE_CONFIG_H
+# include <cc-config.h>
+#endif
+#include <glib/gi18n-lib.h>
+
 enum {
 	COL_TEXT,
 	COL_PAGE,
@@ -53,6 +59,14 @@ demo_window_new(void) {
 void
 demo_window_add(DemoWindow* self, DemoPage* page) {
 	GtkTreeIter iter;
+	g_return_if_fail(DEMO_IS_PAGE(page));
+	g_return_if_fail(GTK_IS_WIDGET(page->widget));
+
+#ifndef G_DISABLE_CHECKS
+	if(G_UNLIKELY(!page->title)) {
+		page->title = _("Untitled Page");
+	}
+#endif
 	self->pages = g_list_prepend(self->pages, page);
 	gint insert_id = gtk_notebook_append_page(GTK_NOTEBOOK(self->notebook),
 						  page->widget, gtk_label_new(page->title));
@@ -78,8 +92,11 @@ tree_selection_changed(GtkTreeSelection* selection, DemoWindow* self) {
 static void
 demo_window_init(DemoWindow* self) {
 	GtkWidget* paned = gtk_hpaned_new();
+	GtkWidget* swin  = gtk_scrolled_window_new(NULL, NULL);
 	GtkTreeModel* model;
 
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(swin), GTK_SHADOW_IN);
+
 	self->treemodel = GTK_TREE_MODEL(gtk_list_store_new(N_COLUMNS, G_TYPE_STRING, G_TYPE_INT));
 	model = gtk_tree_model_sort_new_with_model(self->treemodel);
 	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), COL_TEXT, GTK_SORT_ASCENDING);
@@ -89,7 +106,8 @@ demo_window_init(DemoWindow* self) {
 						    "text", COL_TEXT,
 						    NULL);
 	gtk_widget_show(self->treeview);
-	gtk_paned_pack1(GTK_PANED(paned), self->treeview, FALSE, FALSE);
+	gtk_container_add(GTK_CONTAINER(swin), self->treeview);
+	gtk_paned_pack1(GTK_PANED(paned), swin, FALSE, FALSE);
 
 	self->notebook = gtk_notebook_new();
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(self->notebook), FALSE);
