@@ -1,9 +1,9 @@
-/* this file is part of libccc, criawips' cairo-based canvas
+/* this file is part of libccc
  *
  * AUTHORS
  *       Sven Herzberg        <herzi@gnome-de.org>
  *
- * Copyright (C) 2005 Sven Herzberg
+ * Copyright (C) 2005,2007 Sven Herzberg
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License as
@@ -21,14 +21,21 @@
  * USA
  */
 
-#include "line.h"
+#include "main.h"
 
 #include <gtk/gtklabel.h>
 #include <ccc.h>
 
+#ifdef HAVE_CONFIG_H
+# include <cc-config.h>
+#endif
+#include <glib/gi18n-lib.h>
+
 static void
 update_bounds(CcItem* line, CcView* view, CcDRect* bounds, CcRectangle* rect) {
-	g_return_if_fail(bounds);
+	if(!bounds) {
+		return;
+	}
 
 	cc_rectangle_set_position(rect,
 				  bounds->x1, bounds->y1,
@@ -38,18 +45,16 @@ update_bounds(CcItem* line, CcView* view, CcDRect* bounds, CcRectangle* rect) {
 
 DemoPage*
 line(void) {
-	DemoPage* page = g_new0(DemoPage, 1);
 	CcItem* item   = cc_item_new();
 	CcItem* line   = cc_line_new();
 	CcItem* rect   = cc_rectangle_new();
-	page->title = "Lines";
+	DemoPage* page = demo_page_new(cc_view_widget_new_root(item), _("Lines"));
 	g_signal_connect(line, "all-bounds-changed",
 			 G_CALLBACK(update_bounds), rect);
 	cc_line_move(CC_LINE(line), 5.0, 5.0);
 	cc_line_line(CC_LINE(line), 95.0, 95.0);
 	cc_shape_set_brush_border(CC_SHAPE(rect), cc_brush_color_new(cc_color_new_rgb(1.0, 0.0, 0.0)));
 	cc_shape_set_brush_border(CC_SHAPE(line), cc_brush_color_new(cc_color_new_rgb(0.0, 0.0, 1.0)));
-	page->widget = cc_view_widget_new_root(item);
 	cc_item_append(item, line);
 	cc_item_append(item, rect);
 	return page;
