@@ -25,6 +25,6 @@
 
 void
 Init_ccc(void) {
-	VALUE mod_ccc = rb_define_module("CCCanvas");
+	VALUE mod_ccc = rb_define_module("Ccc");
 }
 
